NOEMBED_PROVIDER_LIST = [
    [
        "https?://(?:[^\\.]+\\.)?(?:youtu\\.be|youtube\\.com/embed)/([a-zA-Z0-9_-]+)",
        "http://noembed.com/embed",
    ],
    [
        "https?://(?:[^\\.]+\\.)?youtube\\.com/watch/?\\?(?:.+&)?v=([^&]+)",
        "http://noembed.com/embed",
    ],
    [
        "https?://www\\.globalgiving\\.org/((micro)?projects|funds)/.*",
        "http://noembed.com/embed",
    ],
    [
        "https?://www\\.giantbomb\\.com/videos/[^/]+/\\d+-\\d+/?",
        "http://noembed.com/embed",
    ],
    ["http://bash\\.org/\\?(\\d+)", "http://noembed.com/embed"],
    ["http://amzn\\.com/([^/]+)", "http://noembed.com/embed"],
    [
        "http://www\\.amazon\\.com/(?:.+/)?[gd]p/(?:product/)?(?:tags-on-product/)?([a-zA-Z0-9]+)",
        "http://noembed.com/embed",
    ],
    ["https://tube.switch.ch/videos/([a-z0-9]+)", "http://noembed.com/embed"],
    ["https?://db\\.tt/[a-zA-Z0-9]+", "http://noembed.com/embed"],
    [
        "https?://www\\.(dropbox\\.com/s/.+\\.(?:jpg|png|gif))",
        "http://noembed.com/embed",
    ],
    ["https?://imgur\\.com/(?:[^\\/]+/)?[0-9a-zA-Z]+$", "http://noembed.com/embed"],
    ["https?://muki\\.io/(embed/)?(.+)", "http://noembed.com/embed"],
    ["https?://vine.co/v/[a-zA-Z0-9]+", "http://noembed.com/embed"],
    [
        "https?://reports\\.zoho\\.com/ZDBDataSheetView\\.cc\\?OBJID=1432535000000003002&STANDALONE=true&INTERVAL=120&DATATYPESYMBOL=false&REMTOOLBAR=false&SEARCHBOX=true&INCLUDETITLE=true&INCLUDEDESC=true&SHOWHIDEOPT=true",
        "http://noembed.com/embed",
    ],
    ["https?://yfrog\\.us/.*", "http://noembed.com/embed"],
    ["https?://.*\\.yfrog\\.com/.*", "http://noembed.com/embed"],
    ["https?://.*\\.wizer\\.me/preview/.*", "http://noembed.com/embed"],
    ["https?://.*\\.wizer\\.me/learn/.*", "http://noembed.com/embed"],
    ["https?://.*\\.wiredrive\\.com/.*", "http://noembed.com/embed"],
    ["https?://vlipsy\\.com/.*", "http://noembed.com/embed"],
    ["https?://player\\.vimeo\\.com/video/.*", "http://noembed.com/embed"],
    ["https?://vimeo\\.com/ondemand/.*/.*", "http://noembed.com/embed"],
    ["https?://vimeo\\.com/groups/.*/videos/.*", "http://noembed.com/embed"],
    ["https?://vimeo\\.com/channels/.*/.*", "http://noembed.com/embed"],
    ["https?://vimeo\\.com/album/.*/video/.*", "http://noembed.com/embed"],
    ["https?://vimeo\\.com/.*", "http://noembed.com/embed"],
    ["https?://vidl\\.it/.*", "http://noembed.com/embed"],
    ["https?://www\\.videojug\\.com/interview/.*", "http://noembed.com/embed"],
    ["https?://www\\.videojug\\.com/film/.*", "http://noembed.com/embed"],
    ["https?://www\\.vevo\\.com/.*", "http://noembed.com/embed"],
    ["https?://veervr\\.tv/videos/.*", "http://noembed.com/embed"],
    ["https?://veer\\.tv/videos/.*", "http://noembed.com/embed"],
    ["https?://uttles\\.com/uttle/.*", "http://noembed.com/embed"],
    ["https?://utposts\\.com/products/.*", "http://noembed.com/embed"],
    ["https?://www\\.utposts\\.com/products/.*", "http://noembed.com/embed"],
    ["https?://.*\\.ustream\\.com/.*", "http://noembed.com/embed"],
    ["https?://.*\\.ustream\\.tv/.*", "http://noembed.com/embed"],
    ["https?://.*\\.uol\\.com\\.br/video/.*", "http://noembed.com/embed"],
    ["https?://.*\\.uol\\.com\\.br/view/.*", "http://noembed.com/embed"],
    ["https?://player\\.ubideo\\.com/.*", "http://noembed.com/embed"],
    ["https?://twitter\\.com/.*/status/.*", "http://noembed.com/embed"],
    ["https?://twitch\\.tv/.*", "http://noembed.com/embed"],
    ["https?://www\\.twitch\\.tv/.*", "http://noembed.com/embed"],
    ["https?://clips\\.twitch\\.tv/.*", "http://noembed.com/embed"],
    ["https?://www\\.topy\\.se/image/.*", "http://noembed.com/embed"],
    ["https?://www\\.tickcounter\\.com/worldclock/.*", "http://noembed.com/embed"],
    ["https?://www\\.tickcounter\\.com/ticker/.*", "http://noembed.com/embed"],
    ["https?://www\\.tickcounter\\.com/countup/.*", "http://noembed.com/embed"],
    ["https?://www\\.tickcounter\\.com/countdown/.*", "http://noembed.com/embed"],
    ["https?://theysaidso\\.com/image/.*", "http://noembed.com/embed"],
    ["https?://.*\\.nytimes\\.com/.*", "http://noembed.com/embed"],
    ["https?://nytimes\\.com/.*", "http://noembed.com/embed"],
    ["https?://www\\.nytimes\\.com/svc/oembed", "http://noembed.com/embed"],
    ["https?://ted\\.com/talks/.*", "http://noembed.com/embed"],
    ["https?://www\\.sway\\.com/.*", "http://noembed.com/embed"],
    ["https?://sway\\.com/.*", "http://noembed.com/embed"],
    ["https?://www\\.sutori\\.com/story/.*", "http://noembed.com/embed"],
    ["https?://content\\.streamonecloud\\.net/embed/.*", "http://noembed.com/embed"],
    ["https?://streamable\\.com/.*", "http://noembed.com/embed"],
    ["https?://.*\\.spreaker\\.com/.*", "http://noembed.com/embed"],
    ["https?://speakerdeck\\.com/.*/.*", "http://noembed.com/embed"],
    ["https?://soundsgood\\.co/playlist/.*", "http://noembed.com/embed"],
    ["https?://play\\.soundsgood\\.co/playlist/.*", "http://noembed.com/embed"],
    ["https?://soundcloud\\.com/.*", "http://noembed.com/embed"],
    ["https?://www\\.socialexplorer\\.com/.*/embed", "http://noembed.com/embed"],
    ["https?://www\\.socialexplorer\\.com/.*/edit", "http://noembed.com/embed"],
    ["https?://www\\.socialexplorer\\.com/.*/view", "http://noembed.com/embed"],
    ["https?://www\\.socialexplorer\\.com/.*/explore", "http://noembed.com/embed"],
    ["https?://.*\\.smugmug\\.com/.*", "http://noembed.com/embed"],
    ["https?://pt\\.slideshare\\.net/.*/.*", "http://noembed.com/embed"],
    ["https?://es\\.slideshare\\.net/.*/.*", "http://noembed.com/embed"],
    ["https?://de\\.slideshare\\.net/.*/.*", "http://noembed.com/embed"],
    ["https?://fr\\.slideshare\\.net/.*/.*", "http://noembed.com/embed"],
    ["https?://www\\.slideshare\\.net/.*/.*", "http://noembed.com/embed"],
    ["https?://sketchfab\\.com/.*/folders/.*", "http://noembed.com/embed"],
    ["https?://sketchfab\\.com/models/.*", "http://noembed.com/embed"],
    ["https?://onsizzle\\.com/i/.*", "http://noembed.com/embed"],
    ["https?://.*\\.silk\\.co/s/embed/.*", "http://noembed.com/embed"],
    ["https?://.*\\.silk\\.co/explore/.*", "http://noembed.com/embed"],
    ["https?://showtheway\\.io/to/.*", "http://noembed.com/embed"],
    ["https?://shoud\\.io/.*", "http://noembed.com/embed"],
    ["https?://shoudio\\.com/.*", "http://noembed.com/embed"],
    ["https?://www\\.shortnote\\.jp/view/notes/.*", "http://noembed.com/embed"],
    ["https?://www\\.scribd\\.com/doc/.*", "http://noembed.com/embed"],
    ["https?://scribblemaps\\.com/maps/view/.*", "http://noembed.com/embed"],
    ["https?://www\\.scribblemaps\\.com/maps/view/.*", "http://noembed.com/embed"],
    ["https?://www\\.screenr\\.com/.*/", "http://noembed.com/embed"],
    ["https?://.*\\.screen9\\.tv/.*", "http://noembed.com/embed"],
    ["https?://console\\.screen9\\.com/.*", "http://noembed.com/embed"],
    ["https?://videos\\.sapo\\.pt/.*", "http://noembed.com/embed"],
    ["https?://roomshare\\.jp/en/post/.*", "http://noembed.com/embed"],
    ["https?://roomshare\\.jp/post/.*", "http://noembed.com/embed"],
    ["https?://www\\.reverbnation\\.com/.*/songs/.*", "http://noembed.com/embed"],
    ["https?://www\\.reverbnation\\.com/.*", "http://noembed.com/embed"],
    [
        "https?://repubhub\\.icopyright\\.net/freePost\\.act\\?.*",
        "http://noembed.com/embed",
    ],
    ["https?://rwire\\.com/.*", "http://noembed.com/embed"],
    ["https?://reddit\\.com/r/.*/comments/.*/.*", "http://noembed.com/embed"],
    ["https?://rapidengage\\.com/s/.*", "http://noembed.com/embed"],
    ["https?://www\\.quizz\\.biz/quizz-.*\\.html", "http://noembed.com/embed"],
    ["https?://www\\.quiz\\.biz/quizz-.*\\.html", "http://noembed.com/embed"],
    ["https?://punters\\.com\\.au/.*", "http://noembed.com/embed"],
    ["https?://www\\.punters\\.com\\.au/.*", "http://noembed.com/embed"],
    ["https?://portfolium\\.com/entry/.*", "http://noembed.com/embed"],
    ["https?://app\\.sellwithport\\.com/#/buyer/.*", "http://noembed.com/embed"],
    ["https?://.*\\.polldaddy\\.com/ratings/.*", "http://noembed.com/embed"],
    ["https?://.*\\.polldaddy\\.com/poll/.*", "http://noembed.com/embed"],
    ["https?://.*\\.polldaddy\\.com/s/.*", "http://noembed.com/embed"],
    ["https?://store\\.pixdor\\.com/map/.*/show", "http://noembed.com/embed"],
    [
        "https?://store\\.pixdor\\.com/place-marker-widget/.*/show",
        "http://noembed.com/embed",
    ],
    ["https?://www\\.pastery\\.net/.*", "http://noembed.com/embed"],
    ["https?://pastery\\.net/.*", "http://noembed.com/embed"],
    ["https?://www\\.oumy\\.com/v/.*", "http://noembed.com/embed"],
    ["https?://orbitvu\\.co/001/.*/1/2/orbittour/.*/view", "http://noembed.com/embed"],
    ["https?://orbitvu\\.co/001/.*/2/orbittour/.*/view", "http://noembed.com/embed"],
    ["https?://orbitvu\\.co/001/.*/ov3602/.*/view", "http://noembed.com/embed"],
    ["https?://orbitvu\\.co/001/.*/ov3601/.*/view", "http://noembed.com/embed"],
    ["https?://orbitvu\\.co/001/.*/ov3601/view", "http://noembed.com/embed"],
    ["https?://on\\.aol\\.com/video/.*", "http://noembed.com/embed"],
    ["https?://official\\.fm/playlists/.*", "http://noembed.com/embed"],
    ["https?://official\\.fm/tracks/.*", "http://noembed.com/embed"],
    ["https?://mix\\.office\\.com/embed/.*", "http://noembed.com/embed"],
    ["https?://mix\\.office\\.com/watch/.*", "http://noembed.com/embed"],
    ["https?://odds\\.com\\.au/.*", "http://noembed.com/embed"],
    ["https?://www\\.odds\\.com\\.au/.*", "http://noembed.com/embed"],
    ["https?://.*\\.nfb\\.ca/film/.*", "http://noembed.com/embed"],
    ["https?://nanoo\\.pro/link/.*", "http://noembed.com/embed"],
    ["https?://.*\\.nanoo\\.pro/link/.*", "http://noembed.com/embed"],
    ["https?://nanoo\\.tv/link/.*", "http://noembed.com/embed"],
    ["https?://.*\\.nanoo\\.tv/link/.*", "http://noembed.com/embed"],
    ["https?://mybeweeg\\.com/w/.*", "http://noembed.com/embed"],
    ["https?://beta\\.modelo\\.io/embedded/.*", "http://noembed.com/embed"],
    ["https?://moby\\.to/.*", "http://noembed.com/embed"],
    ["https?://www\\.mobypicture\\.com/user/.*/view/.*", "http://noembed.com/embed"],
    ["https?://www\\.mixcloud\\.com/.*/.*/", "http://noembed.com/embed"],
    ["https?://meetu\\.ps/.*", "http://noembed.com/embed"],
    ["https?://meetup\\.com/.*", "http://noembed.com/embed"],
    ["https?://me\\.me/i/.*", "http://noembed.com/embed"],
    ["https?://mathembed\\.com/latex\\?inputText=.*", "http://noembed.com/embed"],
    ["https?://learningapps\\.org/.*", "http://noembed.com/embed"],
    ["https?://jdr\\.knacki\\.info/meuh/.*", "http://noembed.com/embed"],
    ["https?://www\\.kitchenbowl\\.com/recipe/.*", "http://noembed.com/embed"],
    ["https?://kit\\.com/.*/.*", "http://noembed.com/embed"],
    ["https?://www\\.kidoju\\.com/fr/x/.*/.*", "http://noembed.com/embed"],
    ["https?://www\\.kidoju\\.com/en/x/.*/.*", "http://noembed.com/embed"],
    ["https?://www\\.kickstarter\\.com/projects/.*", "http://noembed.com/embed"],
    ["https?://www\\.isnare\\.com/.*", "http://noembed.com/embed"],
    ["https?://www\\.instagr\\.am/p/.*", "http://noembed.com/embed"],
    ["https?://www\\.instagram\\.com/p/.*", "http://noembed.com/embed"],
    ["https?://instagr\\.am/p/.*", "http://noembed.com/embed"],
    ["https?://instagram\\.com/p/.*", "http://noembed.com/embed"],
    ["https?://.*\\.inphood\\.com/.*", "http://noembed.com/embed"],
    ["https?://www\\.inoreader\\.com/oembed/", "http://noembed.com/embed"],
    ["https?://infogr\\.am/.*", "http://noembed.com/embed"],
    [
        "https?://player\\.indacolive\\.com/player/jwp/clients/.*",
        "http://noembed.com/embed",
    ],
    ["https?://ifttt\\.com/recipes/.*", "http://noembed.com/embed"],
    ["https?://www\\.ifixit\\.com/Guide/View/.*", "http://noembed.com/embed"],
    ["https?://www\\.hulu\\.com/watch/.*", "http://noembed.com/embed"],
    ["https?://huffduffer\\.com/.*/.*", "http://noembed.com/embed"],
    ["https?://gyazo\\.com/.*", "http://noembed.com/embed"],
    ["https?://media\\.giphy\\.com/media/.*/giphy\\.gif", "http://noembed.com/embed"],
    ["https?://gph\\.is/.*", "http://noembed.com/embed"],
    ["https?://giphy\\.com/gifs/.*", "http://noembed.com/embed"],
    ["https?://www\\.gfycat\\.com/.*", "http://noembed.com/embed"],
    ["https?://gfycat\\.com/.*", "http://noembed.com/embed"],
    ["https?://gty\\.im/.*", "http://noembed.com/embed"],
    ["https?://germany\\.geograph\\.org/.*", "http://noembed.com/embed"],
    ["https?://geo\\.hlipp\\.de/.*", "http://noembed.com/embed"],
    ["https?://geo-en\\.hlipp\\.de/.*", "http://noembed.com/embed"],
    ["https?://.*\\.channel\\.geographs\\.org/.*", "http://noembed.com/embed"],
    ["https?://channel-islands\\.geographs\\.org/.*", "http://noembed.com/embed"],
    ["https?://channel-islands\\.geograph\\.org/.*", "http://noembed.com/embed"],
    ["https?://.*\\.geograph\\.org\\.je/.*", "http://noembed.com/embed"],
    ["https?://.*\\.geograph\\.org\\.gg/.*", "http://noembed.com/embed"],
    [
        "https?://.*\\.wikimedia\\.org/.*_geograph\\.org\\.uk_.*",
        "http://noembed.com/embed",
    ],
    ["https?://.*\\.geograph\\.ie/.*", "http://noembed.com/embed"],
    ["https?://.*\\.geograph\\.co\\.uk/.*", "http://noembed.com/embed"],
    ["https?://.*\\.geograph\\.org\\.uk/.*", "http://noembed.com/embed"],
    ["https?://www\\.funnyordie\\.com/videos/.*", "http://noembed.com/embed"],
    ["https?://framebuzz\\.com/v/.*", "http://noembed.com/embed"],
    [
        "https?://fiso\\.foxsports\\.com\\.au/isomorphic-widget/.*",
        "http://noembed.com/embed",
    ],
    ["https?://flic\\.kr/p/.*", "http://noembed.com/embed"],
    ["https?://.*\\.flickr\\.com/photos/.*", "http://noembed.com/embed"],
    ["https?://.*\\.flat\\.io/score/.*", "http://noembed.com/embed"],
    ["https?://flat\\.io/score/.*", "http://noembed.com/embed"],
    ["https?://www\\.facebook\\.com/video\\.php", "http://noembed.com/embed"],
    ["https?://www\\.facebook\\.com/.*/videos/.*", "http://noembed.com/embed"],
    ["https?://eyrie\\.io/sparkfun/.*", "http://noembed.com/embed"],
    ["https?://eyrie\\.io/board/.*", "http://noembed.com/embed"],
    ["https?://embedarticles\\.com/.*", "http://noembed.com/embed"],
    ["https?://egliseinfo\\.catholique\\.fr/.*", "http://noembed.com/embed"],
    ["https?://edocr\\.com/docs/.*", "http://noembed.com/embed"],
    ["https?://dotsub\\.com/view/.*", "http://noembed.com/embed"],
    ["https?://www\\.docs\\.com/.*", "http://noembed.com/embed"],
    ["https?://docs\\.com/.*", "http://noembed.com/embed"],
    ["https?://docdro\\.id/.*", "http://noembed.com/embed"],
    ["https?://.*\\.docdroid\\.net/.*", "http://noembed.com/embed"],
    ["https?://www\\.dipity\\.com/.*/.*/", "http://noembed.com/embed"],
    ["https?://.*\\.didacte\\.com/a/course/.*", "http://noembed.com/embed"],
    ["https?://sta\\.sh/.*", "http://noembed.com/embed"],
    ["https?://fav\\.me/.*", "http://noembed.com/embed"],
    ["https?://.*\\.deviantart\\.com/.*#/d.*", "http://noembed.com/embed"],
    ["https?://.*\\.deviantart\\.com/art/.*", "http://noembed.com/embed"],
    ["https?://www\\.dailymotion\\.com/video/.*", "http://noembed.com/embed"],
    ["https?://www\\.dailymile\\.com/people/.*/entries/.*", "http://noembed.com/embed"],
    ["https?://app\\.cyranosystems\\.com/msg/.*", "http://noembed.com/embed"],
    ["https?://staging\\.cyranosystems\\.com/msg/.*", "http://noembed.com/embed"],
    ["https?://crowdranking\\.com/.*/.*", "http://noembed.com/embed"],
    ["https?://coub\\.com/embed/.*", "http://noembed.com/embed"],
    ["https?://coub\\.com/view/.*", "http://noembed.com/embed"],
    ["https?://commaful\\.com/play/.*", "http://noembed.com/embed"],
    ["https?://www\\.collegehumor\\.com/video/.*", "http://noembed.com/embed"],
    ["https?://codesandbox\\.io/embed/.*", "http://noembed.com/embed"],
    ["https?://codesandbox\\.io/s/.*", "http://noembed.com/embed"],
    ["https?://www\\.codepoints\\.net/.*", "http://noembed.com/embed"],
    ["https?://codepoints\\.net/.*", "http://noembed.com/embed"],
    ["https?://codepen\\.io/.*", "http://noembed.com/embed"],
    ["https?://clyp\\.it/playlist/.*", "http://noembed.com/embed"],
    ["https?://clyp\\.it/.*", "http://noembed.com/embed"],
    ["https?://www\\.clipland\\.com/v/.*", "http://noembed.com/embed"],
    ["https?://www\\.circuitlab\\.com/circuit/.*", "http://noembed.com/embed"],
    ["https?://chirb\\.it/.*", "http://noembed.com/embed"],
    ["https?://public\\.chartblocks\\.com/c/.*", "http://noembed.com/embed"],
    ["https?://img\\.catbo\\.at/.*", "http://noembed.com/embed"],
    ["https?://carbonhealth\\.com/practice/.*", "http://noembed.com/embed"],
    ["https?://cacoo\\.com/diagrams/.*", "http://noembed.com/embed"],
    ["https?://buttondown\\.email/.*", "http://noembed.com/embed"],
    ["https?://blackfire\\.io/profiles/compare/.*/graph", "http://noembed.com/embed"],
    ["https?://blackfire\\.io/profiles/.*/graph", "http://noembed.com/embed"],
    ["https?://audiosnaps\\.com/k/.*", "http://noembed.com/embed"],
    ["https?://www\\.audiomack\\.com/playlist/.*", "http://noembed.com/embed"],
    ["https?://www\\.audiomack\\.com/album/.*", "http://noembed.com/embed"],
    ["https?://www\\.audiomack\\.com/song/.*", "http://noembed.com/embed"],
    ["https?://animoto\\.com/play/.*", "http://noembed.com/embed"],
    ["https?://animatron\\.com/project/.*", "http://noembed.com/embed"],
    ["https?://www\\.animatron\\.com/project/.*", "http://noembed.com/embed"],
    ["https?://live\\.amcharts\\.com/.*", "http://noembed.com/embed"],
    ["https?://photos\\.app\\.net/.*/.*", "http://noembed.com/embed"],
    ["https?://alpha\\.app\\.net/.*/post/.*", "http://noembed.com/embed"],
    ["https?://www\\.23hq\\.com/.*/photo/.*", "http://noembed.com/embed"],
    ["https?://news.vice\\.com/[^/]+/?", "http://noembed.com/embed"],
    ["http://www\\.theonion\\.com/articles?/[^/]+/?", "http://noembed.com/embed"],
    ["http://arstechnica\\.com/[^/]+/\\d+/\\d+/[^/]+/?$", "http://noembed.com/embed"],
    ["http://tl\\.gd/[^/]+", "http://noembed.com/embed"],
    ["http://www\\.twitlonger\\.com/show/[a-zA-Z0-9]+", "http://noembed.com/embed"],
    ["http://(?:www\\.)?twitpic\\.com/([^/]+)", "http://noembed.com/embed"],
    ["http://picplz\\.com/user/[^/]+/pic/[^/]+", "http://noembed.com/embed"],
    ["http://gfycat\\.com/([a-zA-Z]+)", "http://noembed.com/embed"],
    ["http://lockerz\\.com/[sd]/\\d+", "http://noembed.com/embed"],
    ["http://skit.ch/[^/]+", "http://noembed.com/embed"],
    ["https?://(?:www.)?skitch.com/([^/]+)/[^/]+/.+", "http://noembed.com/embed"],
    ["https?://(?:www\\.)?xkcd\\.com/\\d+/?", "http://noembed.com/embed"],
    ["http://qik\\.com/video/.*", "http://noembed.com/embed"],
    ["https?://(?:www\\.)?vice\\.com/[^/]+/?", "http://noembed.com/embed"],
    [
        "https?://(?:www\\.)?wired\\.com/([^/]+/)?\\d+/\\d+/[^/]+/?$",
        "http://noembed.com/embed",
    ],
    [
        "http://www\\.duffelblog\\.com/\\d{4}/\\d{1,2}/[^/]+/?$",
        "http://noembed.com/embed",
    ],
    ["http://www.traileraddict.com/trailer/[^/]+/trailer", "http://noembed.com/embed"],
    [
        "http://(?:www\\.)?theverge\\.com/\\d{4}/\\d{1,2}/\\d{1,2}/\\d+/[^/]+/?$",
        "http://noembed.com/embed",
    ],
    [
        "http://www\\.monoprice\\.com/products/product\\.asp\\?.*p_id=\\d+",
        "http://noembed.com/embed",
    ],
    ["http://www\\.asciiartfarts\\.com/[0-9]+\\.html", "http://noembed.com/embed"],
    ["http://trailers\\.apple\\.com/trailers/[^/]+/[^/]+", "http://noembed.com/embed"],
    ["https?://(?:www\\.)?vimeo\\.com/.+", "http://noembed.com/embed"],
    [
        "http://www\\.urbandictionary\\.com/define\\.php\\?term=.+",
        "http://noembed.com/embed",
    ],
    [
        "https?://(?:www|mobile\\.)?twitter\\.com/(?:#!/)?([^/]+)/status(?:es)?/(\\d+)",
        "http://noembed.com/embed",
    ],
    ["https?://soundcloud.com/.*/.*", "http://noembed.com/embed"],
    ["https?://v\\.nldg\\.me/.+", "http://noembed.com/embed"],
    ["https?://www\\.nooledge\\.com/\\!/Vid/.+", "http://noembed.com/embed"],
    ["https?://(?:www\\.)spreaker\\.com/.+", "http://noembed.com/embed"],
    ["https?://(?:www\\.)?avclub\\.com/article/[^/]+/?$", "http://noembed.com/embed"],
    ["https?://path\\.com/p/([0-9a-zA-Z]+)$", "http://noembed.com/embed"],
    [
        "http://boingboing\\.net/\\d{4}/\\d{2}/\\d{2}/[^/]+\\.html",
        "http://noembed.com/embed",
    ],
    ["http://cl\\.ly/(?:image/)?[0-9a-zA-Z]+/?$", "http://noembed.com/embed"],
    ["http://www\\.clickhole\\.com/[^/]+/[^/]?", "http://noembed.com/embed"],
]
